@@ -3,7 +3,7 @@
 # If you want to add MIME types,
 # you must add an entry in MimeFamily and may be MimeHashLib
 #-------------------------------------------------------
-# $Revision: 1.16 $ - $Author: eldy $ - $Date: 2003/12/21 01:38:25 $
+# $Revision: 1.25 $ - $Author: eldy $ - $Date: 2009/09/05 11:44:25 $
 
 
 #package AWSMIME;
@@ -13,25 +13,36 @@
 # List of mime's label ("mime id in lower case", "mime text")
 #---------------------------------------------------------------
 %MimeHashLib = (
-'text','Text file',
-'page','HTML or XML static page',
-'script','Dynamic Html page or Script file',
-'image','Image',
-'document','Document',
-'package','Package',
-'archive','Archive',
-'audio','Audio',
-'video','Video',
-'javascript','Javascript file',
-'vbs','Visual Basic script',
-'conf','Config file',
-'css','Cascading Style Sheet file',
-'xsl','Extensible Stylesheet Language file',
-'runtime','HTML dynamic page or Binary runtime',
-'library','Binary library',
-'swf','Macromedia Flash Animation',
-'dtd','Document Type Definition',
-'csv','Comma Separated Value file'
+'text',      'Text file',
+'page',      'HTML or XML static page',
+'script',    'Dynamic Html page or Script file',
+'pl',        'Dynamic Perl Script file',
+'php',       'Dynamic PHP Script file',
+'image',     'Image',
+'document',  'Document',
+'package',   'Package',
+'archive',   'Archive',
+'audio',     'Audio file',
+'video',     'Video file',
+'javascript','JavaScript file',
+'vbs',       'Visual Basic script',
+'conf',      'Config file',
+'css',       'Cascading Style Sheet file',
+'xsl',       'Extensible Stylesheet Language file',
+'runtime',   'Binary runtime',
+'library',   'Binary library',
+'swf',       'Adobe Flash Animation',
+'flv',       'Adobe Flash Video',
+'dtd',       'Document Type Definition',
+'csv',       'Comma Separated Value file',
+'jnlp',      'Java Web Start launch file',
+'lit',       'Microsoft Reader e-book',
+'svg',       'Scalable Vector Graphics',
+'ai',        'Adobe Illustrator file',
+'phshop',    'Adobe Photoshop image file',
+'ttf',       'TrueType scalable font file',
+'fon',       'Font file',
+'pdf',       'Adobe Acrobat file',
 );
 
 # MimeHashIcon
@@ -41,13 +52,18 @@
 %MimeHashIcon = (
 # Text file
 'txt','text',
+'log','text',
 # HTML Static page
 'html','html',
 'htm','html',
 'hdml','html',
 'wml','html',
 'wmlp','html',
+'xhtml','html',
 'xml','html',
+'vak','glasses',
+'sgm','html',
+'sgml','html',
 # HTML Dynamic pages or script
 'asp','script',
 'aspx','script', 
@@ -56,10 +72,10 @@
 'jsp','script',
 'cgi','script',
 'ksh','script',
-'php','script',
-'php3','script',
-'php4','script',
-'pl','script',
+'php','php',
+'php3','php',
+'php4','php',
+'pl','pl',
 'py','script',
 'sh','script',
 'shtml','html',
@@ -71,20 +87,28 @@
 'bmp','image',
 'jpg','image',
 'jpeg','image',
+'cdr','image',
+'ico','image',
+'svg','svg',
+'psd','phshop',
 # Document
 'doc','doc',
+'wmz','doc',
+'rtf','doc',
 'pdf','pdf',
-'xls','other',
-'ppt','other',
-'pps','other',
+'xls','xls',
+'ppt','ppt',
+'pps','ppt',
 'sxw','other',
 'sxc','other',
 'sxi','other',
 'sxd','other',
 'csv','other',
 'xsl','html',
+'lit','lit',
+'ai','ai',
 # Package
-'rpm','archive',
+'rpm',($LogType eq 'S'?'audio':'archive'),
 'deb','archive',
 'msi','archive',
 # Archive
@@ -92,6 +116,7 @@
 'ace','archive',
 'bz2','archive',
 'gz','archive',
+'jar','archive',
 'rar','archive',
 'tar','archive',
 'tgz','archive',
@@ -101,7 +126,6 @@
 # Audio
 'mp3','audio',
 'ogg','audio',
-'rm','audio',
 'wma','audio',
 'wav','audio',
 # Video
@@ -110,31 +134,45 @@
 'mp4','video',
 'mpeg','video',
 'mpg','video',
-'swf','video',
+'rm','real',
+'swf','flash',
+'flv','flash',
+'wmv','video',
+'mov','quicktime',
+'qt','quicktime',
 # Web scripts
-'js','other',
-'vbs','other',
+'js','jscript',
+'vbs','jscript',
 # Config
 'cf','other',
 'conf','other',
-'css','other',
+'css','css',
 'ini','other',
 'dtd','other',
 # Program
 'exe','script',
 'dll','script',
+'jnlp','jnlp',
+# Fonts
+'ttf','ttf',
+'fon','fon',
 );
 
 
 %MimeHashFamily=(
 # Text file
-'txt','page',
+'txt','text',
+'log','text',
 # HTML Static page
 'html','page',
 'htm','page',
 'wml','page',
 'wmlp','page',
+'xhtml','page',
 'xml','page',
+'vak','page',
+'sgm','page',
+'sgml','page',
 # HTML Dynamic pages or script
 'asp','script',
 'aspx','script', 
@@ -143,10 +181,10 @@
 'jsp','script',
 'cgi','script',
 'ksh','script',
-'php','script',
-'php3','script',
-'php4','script',
-'pl','script',
+'php','php',
+'php3','php',
+'php4','php',
+'pl','pl',
 'py','script',
 'sh','script',
 'shtml','script',
@@ -158,9 +196,16 @@
 'bmp','image',
 'jpg','image',
 'jpeg','image',
+'cdr','image',
+'ico','image',
+'svg','svg',
+'psd','phshop',
+'ai','ai',
 # Document
 'doc','document',
-'pdf','document',
+'wmz','document',
+'rtf','document',
+'pdf','pdf',
 'xls','document',
 'ppt','document',
 'pps','document',
@@ -170,8 +215,9 @@
 'sxd','document',
 'csv','csv',
 'xsl','xsl',
+'lit','lit',
 # Package
-'rpm','package',
+'rpm',($LogType eq 'S'?'audio':'package'),
 'deb','package',
 'msi','package',
 # Archive
@@ -179,6 +225,7 @@
 'ace','archive',
 'bz2','archive',
 'gz','archive',
+'jar','archive',
 'rar','archive',
 'tar','archive',
 'tgz','archive',
@@ -188,7 +235,6 @@
 # Audio
 'mp3','audio',
 'ogg','audio',
-'rm','audio',
 'wav','audio',
 'wma','audio',
 # Video
@@ -197,7 +243,12 @@
 'mp4','video',
 'mpeg','video',
 'mpg','video',
+'rm','video',
 'swf','swf',
+'flv','flv',
+'wmv','video',
+'mov','video',
+'qt','video',
 # Web scripts
 'js','javascript',
 'vbs','vbs',
@@ -209,7 +260,11 @@
 'dtd','dtd',
 # Program
 'exe','runtime',
+'jnlp','jnlp',
 'dll','library',
+# Font
+'ttf','ttf',
+'fon','fon',
 );
 
 
